function Polarization1_2015(E0x, E0y, phi, Ns, nfig)

%    function Polarization1(E0x,E0y, phi, Ns, nfig)
%
%    E0x = amplitude of the Ex field component
%    E0y = amplitude of the Ey field component
%    phi = angle phi = phiy-phix in degrees
%     Ns = number of electric field vectors shown
%   nfig = select figure number 
%


angl=0:2*pi/360:2*pi;
phi = phi*pi/180;
alpha = 0.5*atan(2*E0x*E0y*cos(phi)/(E0x^2-E0y^2));

%
%   check if phi is multiple of 180 or 360
%
reminder = mod(phi,pi);

if (reminder ~=0)
  invex1 = (cos(alpha)^2/E0x^2) + (sin(alpha)^2/E0y^2) - (sin(2*alpha)*cos(phi)/(E0x*E0y)); 
  Ex1    = sin(phi)^2*(1/invex1);
  Ex1    = sqrt(Ex1);
  invey1 = (sin(alpha)^2/E0x^2) + (cos(alpha)^2/E0y^2) + (sin(2*alpha)*cos(phi)/(E0x*E0y)); 
  Ey1    = sin(phi)^2*(1/invey1);
  Ey1    = sqrt(Ey1);
  Emax   = max(Ex1,Ey1);
  Emin   = min(Ex1,Ey1);
  ee     = Emin/Emax;
else
  Ex1 = E0x;
  Ey1 = E0y;
  Emax   = max(Ex1,Ey1);
  Emin   = min(Ex1,Ey1);
  ee     = Emin/Emax;
  reminder1 = mod(phi,2*pi);
  if (reminder1 == 0)
      alpha = atan2(Ey1,Ex1);
    else
      alpha = -atan2(Ey1,Ex1);
  end
end

figure(nfig)

NN = 360/Ns;

for i1 = 0:Ns
  
  ii = (i1-1)*(NN);
  ang = (2*pi/360)*ii:(2*pi/360):(2*pi/360)*(ii+NN);
  Ex =  E0x*cos(ang);
  Ey =  E0y*cos(ang+phi);
  
  plot(Ex,Ey,'r','Linewidth',2)
  axis equal
  if E0x == 0
     axis([-E0y E0y -E0y E0y])
  elseif E0y == 0
     axis([-E0x E0x -E0x E0x])
  else
     axis([-E0x E0x -E0y E0y])
  end

  
  if i1==1
    set(gca,'Fontsize',14,'Fontweight','bold')
    xlabel('x-component of electric field, E_x','Fontsize',14)
    ylabel('y-component of electric field, E_y','Fontsize',14)
    title(['E_{ox} = ',num2str(E0x),', E_{0y} = ',num2str(E0y),', \phi (deg) = ',num2str(phi*180/pi), ...
           ', \alpha (deg) = ',num2str(alpha*180/pi), ', e = ',num2str(ee), ...
           ', E_{x1} = ',num2str(Ex1),',  E_{y1} = ',num2str(Ey1)],'Fontsize',10)
    else
  end
  
  hold on
  
  
  p0 = [0 0];
  p1 = [Ex(end),Ey(end)];

  [hv1,hv2]=vectarrow1_2015(p0,p1);
  pause(0.1)
  if i1<Ns
    delete(hv1)
    delete(hv2)
  else
  end
  
end

hold off



